PyCampbellCR1000 is written and maintained by Salem Harrache and
various contributors:

Development Lead
````````````````

- Salem Harrache <salem@harrache.info>

Patches and Suggestions
```````````````````````

- Lionel Darras

Original authors
````````````````

- This project is based on `Pypak project`_ 
  by Dietrich Feist, Max Planck Institute for Biogeochemistry, Jena Germany

.. _`Pypak project`: http://sourceforge.net/projects/pypak/
